==> deepin-camera_1.0.0.15.orig.tar.xz: deepin-camera-1.0.0.15/src/translations/deepin-camera_zh_TW.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_TW" version="2.1">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>正在錄製影片，是否關閉？</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>開啟資料夾</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <source>None</source>
        <translation>無</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>開啟資料夾</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>您沒有權限操作此資料夾</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation>資料夾無效</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>開啟資料夾</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>基本設定</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>儲存路徑</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>拍照設定</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>連拍</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>拍照延時設定</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>輸出設定</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>輸出格式</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4張</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10張</translation>
    </message>
    <message>
        <source>None</source>
        <translation>無</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>相機</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>相機是一款簡單易用的攝影機應用工具，可實現拍照、錄製影片等功能。</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>文件未儲存</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>儲存位置：</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>照片：</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>影片：</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>解析度設定</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation>解析度：</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation>拍照</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation>錄製影片</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>結束拍照</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>無</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>未連接攝影機</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>攝影機已被占用</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>結束錄製</translation>
    </message>
</context>
</TS>

==> deepin-camera_1.1.2.orig.tar.xz: deepin-camera-1.1.2/src/translations/deepin-camera_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>正在錄製影片，是否關閉？</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>開啟資料夾</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <source>None</source>
        <translation>無</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>開啟資料夾</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>列印</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>您沒有權限操作此資料夾</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">資料夾無效</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>開啟資料夾</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>基本設定</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>儲存路徑</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>拍照設定</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>連拍</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>拍照延時設定</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>輸出設定</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>輸出格式</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4張</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10張</translation>
    </message>
    <message>
        <source>None</source>
        <translation>無</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>相機</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>相機是一款簡單易用的攝影機應用工具，可實現拍照、錄製影片等功能。</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>文件未儲存</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">儲存位置：</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>照片：</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>影片：</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>解析度設定</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation>解析度：</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>照片存儲位置：</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>影片存儲位置：</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>音效</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>相機</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>結束錄製</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>打開</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>列印</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>說明</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>顯示快捷鍵</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>結束拍照</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>喚起右鍵菜單</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation>拍照</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation>錄製影片</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>結束拍照</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>無</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>未連接攝影機</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>攝影機已被占用</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>結束錄製</translation>
    </message>
</context>
</TS>
